@@ -13,8 +13,4 @@ class Pathname
   def blank?
     to_s.empty?
   end
-
-  def present? # :nodoc:
-    !to_s.empty?
-  end
 end
